import React, { useEffect, useState } from "react";
import {
  View,
  Text,
  StyleSheet,
  Button,
  ActivityIndicator,
} from "react-native";
import { LOCALBACKEND } from "../../env";
import AsyncStorage from "@react-native-async-storage/async-storage";

export default function PatientAllPractitioners({ navigation, router }) {
  const [data, setData] = useState([]);
  const [stellarPublicKey, setStellarPublicKey] = useState("");
  const [isRequested, setRequested] = useState(false);

  useEffect(() => {
    fetchData();
  }, []);

  const fetchData = async () => {
    try {
      const practitionerUrl = LOCALBACKEND + "/practitioner/allpractitioner";
      const response = await fetch(practitionerUrl);
      const json = await response.json();
      setData(json.data);
    } catch (errorWhenFetchingPractitionerData) {
      console.error(
        "Error fetching practitioner data:",
        errorWhenFetchingPractitionerData
      );
    }
  };

  const renderItem = (item) => {
    return (
      <View style={styles.item} key={item._id}>
        <Text>Full Name: {item.fullname}</Text>
        <Text>Public Key: {item.publickey}</Text>
        <Text>Workspace: {item.workspace}</Text>
        <Button
          color="#703BE7"
          title="Request"
          onPress={() => handleRequest(item)}
        />
      </View>
    );
  };

  const handleRequest = async (item) => {
    setRequested(true);
    try {
      const value = await AsyncStorage.getItem("patientStellarPublicKey");
      if (value != null) {
        setStellarPublicKey(value);

        //build the JSON to create the request
        const reqObj = {
          patient: value,
          practitionerKey: item.publickey,
        };

        const reqUrl = LOCALBACKEND + `/patient/request`;

        try {
          const reqResponse = await fetch(reqUrl, {
            method: "POST",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify(reqObj),
          });

          const responseData = await reqResponse.json();
          setRequested(false);
        } catch (errorWhenSendingReqObj) {
          console.log("Error when sending request to practitioner");
        }
      } else {
        console.log("Empty key");
      }
    } catch (errorWhenPublicKey) {
      console.error(
        "Error fetching public key from async storage data:",
        errorWhenPublicKey
      );
      setRequested(false);
    }
    // Handle the request for the specific item by requesting the practitioner
    console.log("Requested:", item);
  };

  return (
    <View style={styles.container}>
      {isRequested ? (
        <ActivityIndicator size="large" color="#000" />
      ) : (
        <>{data.map((item) => renderItem(item))}</>
      )}
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: "center",
    padding: 20,
  },
  text: {
    fontSize: 24,
    fontWeight: "bold",
  },
  item: {
    padding: 10,
  },
});
