import React, { useState } from "react";
import { View, TextInput, Button, Alert, StyleSheet } from "react-native";
import { LOCALBACKEND } from "../../../env";
import EncryptWithServerKey from "../../../services/encryptByServerKey";

export default function PatientLogin({ navigation, route }) {
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");

  const handleLogin = async () => {
    const encryptedUsername = EncryptWithServerKey(username);
    const encryptedPassword = EncryptWithServerKey(password);
    try {
      const loginUrl = LOCALBACKEND + `/patient/login`;
      const response = await fetch(loginUrl, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          username: encryptedUsername,
          password: encryptedPassword,
        }),
      });

      if (response.ok) {
        navigation.navigate("PatientMainMenu");
      } else {
        // Login failed, show an error message
        Alert.alert("Login Failed", "Invalid username or password");
      }
    } catch (error) {
      console.error(error);
      // Handle any network or server errors
      Alert.alert("Error", "An error occurred while logging in");
    }
  };

  return (
    <View style={styles.container}>
      <TextInput
        style={styles.input}
        placeholder="Username"
        value={username}
        onChangeText={setUsername}
      />
      <TextInput
        style={styles.input}
        placeholder="Password"
        value={password}
        onChangeText={setPassword}
        secureTextEntry
      />
      <Button title="Login" onPress={handleLogin} color="#703BE7" />
    </View>
  );
}
const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: "center",
    justifyContent: "center",
  },
  input: {
    width: "80%",
    height: 40,
    marginVertical: 10,
    paddingHorizontal: 10,
    borderColor: "gray",
    borderWidth: 1,
    borderRadius: 5,
  },
  button: {
    width: "80%",
    height: 60, // Adjust the height value to make the button taller
    backgroundColor: "#560CCE",
    justifyContent: "center",
    alignItems: "center",
    borderRadius: 30, // Adjust the border radius value to make the edges rounder
    marginTop: 10,
  },
  buttonText: {
    color: "white",
    fontSize: 16,
    fontWeight: "bold",
  },
});
