import { useEffect, useState } from "react";
import { LOCALBACKEND } from "../../env";
import {
  Button,
  StyleSheet,
  View,
  Text,
  Alert,
  ActivityIndicator,
} from "react-native";
import AsyncStorage from "@react-native-async-storage/async-storage";
import EncryptWithServerKey from "../../services/encryptByServerKey";
import Toast from "react-native-toast-message";

export default function TreatingPatients({ navigation }) {
  const [data, setData] = useState([]);
  const [isRequested, setRequested] = useState(false);

  useEffect(() => {
    fetchRequests();
  }, []);

  const fetchRequests = async () => {
    //get key from async storage
    try {
      const practitionerKey = await AsyncStorage.getItem(
        "practitionerStellarPublicKey"
      );
      try {
        const requestUrl =
          LOCALBACKEND + `/practitioner/treatingPatients/${practitionerKey}`;

        console.log(requestUrl);

        const response = await fetch(requestUrl);
        const json = await response.json();
        setData(json.data);
      } catch (errorFetchingRequests) {
        console.log(
          "Error when fetching request data : ",
          errorFetchingRequests
        );
      }
    } catch (errorWhenGettingKey) {
      console.log(
        "Error when getting the public key from the async storage : ",
        errorWhenGettingKey
      );
    }
  };

  const renderItem = (item) => {
    return (
      <View style={styles.item} key={item._id}>
        <Text>Key: {item.patient}</Text>
        <Button
          title="Request EHR"
          color="#703BE7"
          onPress={() => handleRequesting(item)}
        ></Button>
      </View>
    );
  };

  const handleRequesting = async (item) => {
    setRequested(true);
    //get the practitioner keys
    try {
      const practitionerKey = await AsyncStorage.getItem(
        "practitionerStellarPublicKey"
      );
      const practitionerSecretKey = await AsyncStorage.getItem(
        "practitionerStellarSecretKey"
      );
      const practitionerRsaKey = await AsyncStorage.getItem(
        "practitionerRsaPublicKey"
      );

      //send the post request for requesting NFT

      const encryptedPractitionerKey = EncryptWithServerKey(practitionerKey);
      const encryptedPractitionerSeed = EncryptWithServerKey(
        practitionerSecretKey
      );
      const encryptedRsaKey = EncryptWithServerKey(practitionerRsaKey);
      const encryptedPatientKey = EncryptWithServerKey(item.patient);

      const requestOj = {
        practitionerkey: encryptedPractitionerKey,
        practitionerseed: encryptedPractitionerSeed,
        patient: encryptedPatientKey,
        practitionerrsa: encryptedRsaKey,
      };

      const nftRequestEnndpoint = LOCALBACKEND + `/practitioner/requestnft`;

      try {
        const nftRequestResponse = await fetch(nftRequestEnndpoint, {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify(requestOj),
        });
        setRequested(false);
        Toast.show({
          type: "success", // 'success', 'error', 'info', 'warning'
          text1: "Request added",
          visibilityTime: 3000, // Duration to show the toast in milliseconds
          autoHide: true,
        });
        const responseData = await nftRequestResponse.json();
        setRequested(false);
      } catch (error) {
        setRequested(false);

        console.error("Error when calling the request NFT");
      }
    } catch (errorWheGettingKeyPair) {
      setRequested(false);

      console.error("Error when getting keypair");
    }
  };

  return (
    <View style={styles.container}>
      {isRequested ? (
        <ActivityIndicator color="#000" size="large"></ActivityIndicator>
      ) : (
        <>
          <View>{data.map((item) => renderItem(item))}</View>
        </>
      )}
      <Toast ref={(ref) => Toast.setRef(ref)} />
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    padding: 30,
    alignItems: "center",
  },
  text: {
    fontSize: 24,
    fontWeight: "bold",
  },
  item: {
    padding: 20,
  },
});
